
/*
 * *****************************************************************************************
 *
 * 		Copyright (C) 2014-2018 Gowin Semiconductor Technology Co.,Ltd.
 * 		
 * @file		main.c
 * @author		Embedded Development Team
 * @version		V1.0.0
 * @date		2018-5-1 09:00:00
 * @brief		Main program body.
 ******************************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "gw1ns2c.h"
#include <stdio.h>
#include <stdlib.h>

#define FLASH_DETAIN1_BASE        (FLASH_BASE + 0x1F800 )   /* !<  FLASH Detain Address 1F800*/
#define FLASH_DETAIN2_BASE        (FLASH_BASE + 0x1FC00 )   /* !<  FLASH Detain Address 1FC00*/

void UartInit(void);
void ReadFlashDetain(uint32_t *data);
void Delay_ms(__IO uint32_t delay_ms);
char* int2str(int num,char*str,int radix);

char buff[20];
volatile uint32_t counter;

int main()
{   
  uint32_t data[256] = {0};
  uint32_t i = 0;

  //Init System
  SystemInit();
	
  //Init Uart
  UartInit();
  UART_SendString(UART0,"\r\nUart Initial finished\r\n");

  UART_SendString(UART0,"Flash 2k Detain address Test:");
  ReadFlashDetain(data);
	
  for(i=0;i<256;i++)
  {
	UART_SendString(UART0,"\r\n");
	UART_SendString(UART0,int2str((uint32_t)(FLASH_DETAIN2_BASE+i*4),buff,16));
	UART_SendString(UART0,":");
	UART_SendString(UART0," ");
    UART_SendString(UART0,int2str(data[i],buff,16));
  }
}

void UartInit(void)
{
  UART_InitTypeDef UART_InitStruct;
	
  UART_InitStruct.UART_Mode.UARTMode_Tx = ENABLE;
  UART_InitStruct.UART_Mode.UARTMode_Rx = ENABLE;
  UART_InitStruct.UART_Int.UARTInt_Tx = DISABLE;
  UART_InitStruct.UART_Int.UARTInt_Rx = DISABLE;
  UART_InitStruct.UART_Ovr.UARTOvr_Tx = DISABLE;
  UART_InitStruct.UART_Ovr.UARTOvr_Rx = DISABLE;
  UART_InitStruct.UART_Hstm = DISABLE;
  UART_InitStruct.UART_BaudRate = 115200;//Baud Rate
	
  UART_Init(UART0,&UART_InitStruct);
}

void Delay_ms(__IO uint32_t delay_ms)
{
  for(delay_ms=delay_ms*8500; delay_ms != 0; delay_ms--);
}

void ReadFlashDetain(uint32_t *data)
{
	uint32_t i=0;
	for(i=0;i<256;i++)
	{
		*(data+i) = *(uint32_t*)(FLASH_DETAIN2_BASE+i*4);
	}
}

char* int2str(int num,char*str,int radix)
{
	char index[]="0123456789ABCDEF";
	unsigned unum;
	int i=0,j,k;
	char temp;

	if(radix==10&&num<0)
	{
		unum=(unsigned)-num;
		str[i++]='-';
	}
	else
	{
		unum=(unsigned)num;
	}

	do
	{
		str[i++]=index[unum%(unsigned)radix];
		unum/=radix;
	}while(unum);
	str[i]='\0';

	if(str[0]=='-')
	{
		k=1;
	}
	else
	{
		k=0;
	}
	
	for(j=k;j<=(i-1)/2;j++)
	{
		temp=str[j];
		str[j]=str[i-1+k-j];
		str[i-1+k-j]=temp;
	}
	
	return str;
}
